@@ -37,10 +37,12 @@ class Issues:
         for index, issue in enumerate(self._issues):
             # TODO could just be yaml format?
             click.secho(
-                f"\n  {index+1}. {issue.description}", fg="yellow", bold=True,
+                f"\n  {index+1}. {issue.description}",
+                fg="yellow",
+                bold=True,
             )
             click.secho(
-                f"     https://combine.dropseed.io/checks/#{issue.type}\n", fg="yellow"
+                f"     https://combine.dropseed.dev/checks/#{issue.type}\n", fg="yellow"
             )
             for k, v in issue.context.items():
                 click.secho(f"     {k}: {pformat(v)}", fg="yellow")
