@@ -2,8 +2,8 @@ from .core import File
 
 
 class IgnoredFile(File):
-    def get_path_for_output(self):
+    def _get_output_relative_path(self):
         return None
 
-    def render_to_output(self, *args, **kwargs):
+    def _render_to_output(self, *args, **kwargs):
         return None
